# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: NoticeMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import I18nCopyWriting_pb2 as I18nCopyWriting__pb2
import RichTextNoticeMessage_pb2 as RichTextNoticeMessage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13NoticeMessage.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x15I18nCopyWriting.proto\x1a\x1bRichTextNoticeMessage.proto\"\xa1\x01\n\rNoticeMessage\x12\x44\n\x0erichTextNotice\x18\x02 \x01(\x0b\x32,.AcFunDanmu.Im.Message.RichTextNoticeMessage\x12\x0b\n\x03msg\x18\x05 \x01(\t\x12=\n\x0fi18nCopyWriting\x18\n \x01(\x0b\x32$.AcFunDanmu.Im.Basic.I18nCopyWritingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'NoticeMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTICEMESSAGE._serialized_start=99
  _NOTICEMESSAGE._serialized_end=260
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveScStatusChanged.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bZtLiveScStatusChanged.proto\x12\nAcFunDanmu\"\xb7\x02\n\x15ZtLiveScStatusChanged\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.AcFunDanmu.ZtLiveScStatusChanged.Type\x12\x18\n\x10maxRandomDelayMs\x18\x02 \x01(\x03\x12@\n\nbannedInfo\x18\x03 \x01(\x0b\x32,.AcFunDanmu.ZtLiveScStatusChanged.BannedInfo\x1a*\n\nBannedInfo\x12\x11\n\tbanReason\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\t\"`\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bLIVE_CLOSED\x10\x01\x12\x13\n\x0fNEW_LIVE_OPENED\x10\x02\x12\x14\n\x10LIVE_URL_CHANGED\x10\x03\x12\x0f\n\x0bLIVE_BANNED\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveScStatusChanged_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVESCSTATUSCHANGED._serialized_start=44
  _ZTLIVESCSTATUSCHANGED._serialized_end=355
  _ZTLIVESCSTATUSCHANGED_BANNEDINFO._serialized_start=215
  _ZTLIVESCSTATUSCHANGED_BANNEDINFO._serialized_end=257
  _ZTLIVESCSTATUSCHANGED_TYPE._serialized_start=259
  _ZTLIVESCSTATUSCHANGED_TYPE._serialized_end=355
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupCreateRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupLabel_pb2 as GroupLabel__pb2
import GroupType_pb2 as GroupType__pb2
import Location_pb2 as Location__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18GroupCreateRequest.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x10GroupLabel.proto\x1a\x0fGroupType.proto\x1a\x0eLocation.proto\x1a\nUser.proto\"\xd0\x02\n\x12GroupCreateRequest\x12*\n\x07members\x18\x01 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x11\n\tgroupName\x18\x02 \x01(\t\x12\x14\n\x0cgroupHeadUrl\x18\x03 \x01(\t\x12\x37\n\x08location\x18\x04 \x01(\x0b\x32%.AcFunDanmu.Im.Cloud.Message.Location\x12\x0b\n\x03tag\x18\x05 \x01(\t\x12\x39\n\tgroupType\x18\x06 \x01(\x0e\x32&.AcFunDanmu.Im.Cloud.Message.GroupType\x12\x14\n\x0cintroduction\x18\x07 \x01(\t\x12\x16\n\x0eoriginalTarget\x18\x08 \x01(\t\x12\x36\n\x05label\x18\t \x03(\x0b\x32\'.AcFunDanmu.Im.Cloud.Message.GroupLabelb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupCreateRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPCREATEREQUEST._serialized_start=121
  _GROUPCREATEREQUEST._serialized_end=457
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PullNewResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Message_pb2 as Message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15PullNewResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\rMessage.proto\"C\n\x0fPullNewResponse\x12\x30\n\x08messages\x18\x01 \x03(\x0b\x32\x1e.AcFunDanmu.Im.Message.Messageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PullNewResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PULLNEWRESPONSE._serialized_start=63
  _PULLNEWRESPONSE._serialized_end=130
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupInviteResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupMember_pb2 as GroupMember__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19GroupInviteResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x11GroupMember.proto\"\xf1\x01\n\x13GroupInviteResponse\x12\x0f\n\x07groupId\x18\x01 \x01(\t\x12S\n\x0cinviteStatus\x18\x02 \x01(\x0e\x32=.AcFunDanmu.Im.Cloud.Message.GroupInviteResponse.InviteStatus\x12\x39\n\x07members\x18\x03 \x03(\x0b\x32(.AcFunDanmu.Im.Cloud.Message.GroupMember\"9\n\x0cInviteStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x08\n\x04SUCC\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupInviteResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPINVITERESPONSE._serialized_start=78
  _GROUPINVITERESPONSE._serialized_end=319
  _GROUPINVITERESPONSE_INVITESTATUS._serialized_start=262
  _GROUPINVITERESPONSE_INVITESTATUS._serialized_end=319
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MessageBatchSendResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SendMessageResponse_pb2 as SendMessageResponse__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eMessageBatchSendResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x19SendMessageResponse.proto\"X\n\x18MessageBatchSendResponse\x12<\n\x08response\x18\x01 \x03(\x0b\x32*.AcFunDanmu.Im.Message.SendMessageResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MessageBatchSendResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGEBATCHSENDRESPONSE._serialized_start=84
  _MESSAGEBATCHSENDRESPONSE._serialized_end=172
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ManagerSettingRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bManagerSettingRequest.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\nUser.proto\"\xdb\x01\n\x15ManagerSettingRequest\x12*\n\x07manager\x18\x01 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12O\n\toperation\x18\x02 \x01(\x0e\x32<.AcFunDanmu.Im.Cloud.Message.ManagerSettingRequest.Operation\x12\x0f\n\x07groupId\x18\x03 \x01(\t\"4\n\tOperation\x12\x15\n\x11UNKNOWN_OPERATION\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\x07\n\x03\x44\x45L\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ManagerSettingRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MANAGERSETTINGREQUEST._serialized_start=73
  _MANAGERSETTINGREQUEST._serialized_end=292
  _MANAGERSETTINGREQUEST_OPERATION._serialized_start=240
  _MANAGERSETTINGREQUEST_OPERATION._serialized_end=292
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveCsCmd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11ZtLiveCsCmd.proto\x12\nAcFunDanmu\"O\n\x0bZtLiveCsCmd\x12\x0f\n\x07\x63mdType\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x0e\n\x06ticket\x18\x03 \x01(\t\x12\x0e\n\x06liveId\x18\x04 \x01(\t\"Z\n\x0eZtLiveCsCmdAck\x12\x12\n\ncmdAckType\x18\x01 \x01(\t\x12\x11\n\terrorCode\x18\x02 \x01(\x03\x12\x10\n\x08\x65rrorMsg\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveCsCmd_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVECSCMD._serialized_start=33
  _ZTLIVECSCMD._serialized_end=112
  _ZTLIVECSCMDACK._serialized_start=114
  _ZTLIVECSCMDACK._serialized_end=204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DownstreamPayload.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x44ownstreamPayload.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xa5\x01\n\x11\x44ownstreamPayload\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\r\n\x05seqId\x18\x02 \x01(\x03\x12\x11\n\terrorCode\x18\x03 \x01(\x05\x12\x13\n\x0bpayloadData\x18\x04 \x01(\x0c\x12\x10\n\x08\x65rrorMsg\x18\x05 \x01(\t\x12\x11\n\terrorData\x18\x06 \x01(\x0c\x12\x0e\n\x06subBiz\x18\x07 \x01(\t\x12\x13\n\x0bklinkPushId\x18\x08 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DownstreamPayload_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOWNSTREAMPAYLOAD._serialized_start=49
  _DOWNSTREAMPAYLOAD._serialized_end=214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MessageReceiptDetailGetRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTarget_pb2 as ChatTarget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$MessageReceiptDetailGetRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x10\x43hatTarget.proto\"f\n\x1eMessageReceiptDetailGetRequest\x12\r\n\x05seqId\x18\x01 \x01(\x03\x12\x35\n\nchatTarget\x18\x02 \x01(\x0b\x32!.AcFunDanmu.Im.Message.ChatTargetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MessageReceiptDetailGetRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGERECEIPTDETAILGETREQUEST._serialized_start=81
  _MESSAGERECEIPTDETAILGETREQUEST._serialized_end=183
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveUserIdentity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ZtLiveUserIdentity.proto\x12\nAcFunDanmu\"\x8a\x01\n\x12ZtLiveUserIdentity\x12?\n\x0bmanagerType\x18\x01 \x01(\x0e\x32*.AcFunDanmu.ZtLiveUserIdentity.ManagerType\"3\n\x0bManagerType\x12\x18\n\x14UNKNOWN_MANAGER_TYPE\x10\x00\x12\n\n\x06NORMAL\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveUserIdentity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVEUSERIDENTITY._serialized_start=41
  _ZTLIVEUSERIDENTITY._serialized_end=179
  _ZTLIVEUSERIDENTITY_MANAGERTYPE._serialized_start=128
  _ZTLIVEUSERIDENTITY_MANAGERTYPE._serialized_end=179
# @@protoc_insertion_point(module_scope)



"""Contains various maps for protobuf types, including encoding/decoding
   functions, wiretypes and default types
"""
from google.protobuf.internal import wire_format
from . import varint, fixed, length_delim

encoders = {
    'uint': varint.encode_uvarint,
    'int': varint.encode_varint,
    'sint': varint.encode_svarint,
    'fixed32': fixed.encode_fixed32,
    'sfixed32': fixed.encode_sfixed32,
    'float': fixed.encode_float,
    'fixed64': fixed.encode_fixed64,
    'sfixed64': fixed.encode_sfixed64,
    'double': fixed.encode_double,
    'bytes': length_delim.encode_bytes,
    'packed_uint': length_delim.generate_packed_encoder(varint.encode_uvarint),
    'packed_int': length_delim.generate_packed_encoder(varint.encode_varint),
    'packed_sint': length_delim.generate_packed_encoder(varint.encode_svarint),
    'packed_fixed32': length_delim.generate_packed_encoder(fixed.encode_fixed32),
    'packed_sfixed32': length_delim.generate_packed_encoder(fixed.encode_sfixed32),
    'packed_float': length_delim.generate_packed_encoder(fixed.encode_float),
    'packed_fixed64': length_delim.generate_packed_encoder(fixed.encode_fixed64),
    'packed_sfixed64': length_delim.generate_packed_encoder(fixed.encode_sfixed64),
    'packed_double': length_delim.generate_packed_encoder(fixed.encode_double)
}

decoders = {
    'uint': varint.decode_uvarint,
    'int': varint.decode_varint,
    'sint': varint.decode_svarint,
    'fixed32': fixed.decode_fixed32,
    'sfixed32': fixed.decode_sfixed32,
    'float': fixed.decode_float,
    'fixed64': fixed.decode_fixed64,
    'sfixed64': fixed.decode_sfixed64,
    'double': fixed.decode_double,
    'bytes': length_delim.decode_bytes,
    'str': length_delim.decode_str,
    'packed_uint': length_delim.generate_packed_decoder(varint.decode_uvarint),
    'packed_int': length_delim.generate_packed_decoder(varint.decode_varint),
    'packed_sint': length_delim.generate_packed_decoder(varint.decode_svarint),
    'packed_fixed32': length_delim.generate_packed_decoder(fixed.decode_fixed32),
    'packed_sfixed32': length_delim.generate_packed_decoder(fixed.decode_sfixed32),
    'packed_float': length_delim.generate_packed_decoder(fixed.decode_float),
    'packed_fixed64': length_delim.generate_packed_decoder(fixed.decode_fixed64),
    'packed_sfixed64': length_delim.generate_packed_decoder(fixed.decode_sfixed64),
    'packed_double': length_delim.generate_packed_decoder(fixed.decode_double)
}

wiretypes = {
    'uint': wire_format.WIRETYPE_VARINT,
    'int': wire_format.WIRETYPE_VARINT,
    'sint': wire_format.WIRETYPE_VARINT,
    'fixed32': wire_format.WIRETYPE_FIXED32,
    'sfixed32': wire_format.WIRETYPE_FIXED32,
    'float': wire_format.WIRETYPE_FIXED32,
    'fixed64': wire_format.WIRETYPE_FIXED64,
    'sfixed64': wire_format.WIRETYPE_FIXED64,
    'double': wire_format.WIRETYPE_FIXED64,
    'bytes':  wire_format.WIRETYPE_LENGTH_DELIMITED,
    'str':  wire_format.WIRETYPE_LENGTH_DELIMITED,
    'message':  wire_format.WIRETYPE_LENGTH_DELIMITED,
    'group': wire_format.WIRETYPE_START_GROUP,
    'packed_uint': wire_format.WIRETYPE_LENGTH_DELIMITED,
    'packed_int': wire_format.WIRETYPE_LENGTH_DELIMITED,
    'packed_sint': wire_format.WIRETYPE_LENGTH_DELIMITED,
    'packed_fixed32': wire_format.WIRETYPE_LENGTH_DELIMITED,
    'packed_sfixed32': wire_format.WIRETYPE_LENGTH_DELIMITED,
    'packed_float': wire_format.WIRETYPE_LENGTH_DELIMITED,
    'packed_fixed64': wire_format.WIRETYPE_LENGTH_DELIMITED,
    'packed_sfixed64': wire_format.WIRETYPE_LENGTH_DELIMITED,
    'packed_double': wire_format.WIRETYPE_LENGTH_DELIMITED
}

wire_type_defaults = {
    wire_format.WIRETYPE_VARINT: 'int',
    wire_format.WIRETYPE_FIXED32: 'fixed32',
    wire_format.WIRETYPE_FIXED64: 'fixed64',
    wire_format.WIRETYPE_LENGTH_DELIMITED: None,
    wire_format.WIRETYPE_START_GROUP: 'group',
    wire_format.WIRETYPE_END_GROUP: None
    }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MessageStatusSettingListRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import MessageReceiveStatus_pb2 as MessageReceiveStatus__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%MessageStatusSettingListRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x1aMessageReceiveStatus.proto\"}\n\x1fMessageStatusSettingListRequest\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.AcFunDanmu.Im.Message.MessageReceiveStatus\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MessageStatusSettingListRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGESTATUSSETTINGLISTREQUEST._serialized_start=92
  _MESSAGESTATUSSETTINGLISTREQUEST._serialized_end=217
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AccessPointsConfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AccessPoint_pb2 as AccessPoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x41\x63\x63\x65ssPointsConfig.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\x11\x41\x63\x63\x65ssPoint.proto\"\xd7\x01\n\x12\x41\x63\x63\x65ssPointsConfig\x12\x34\n\noptimalAps\x18\x01 \x03(\x0b\x32 .AcFunDanmu.Im.Basic.AccessPoint\x12\x33\n\tbackupAps\x18\x02 \x03(\x0b\x32 .AcFunDanmu.Im.Basic.AccessPoint\x12\x16\n\x0e\x61vailablePorts\x18\x03 \x03(\r\x12>\n\x14\x66orceLastConnectedAp\x18\x04 \x01(\x0b\x32 .AcFunDanmu.Im.Basic.AccessPointb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AccessPointsConfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCESSPOINTSCONFIG._serialized_start=69
  _ACCESSPOINTSCONFIG._serialized_end=284
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CsAckErrorCode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x43sAckErrorCode.proto\x12\nAcFunDanmu*\xda\x01\n\x0e\x43sAckErrorCode\x12\x12\n\x0eSUCCESS_CS_ACK\x10\x00\x12\x0f\n\x0bLIVE_CLOSED\x10\x01\x12\x12\n\x0eTICKET_ILLEGAL\x10\x02\x12\x12\n\x0e\x41TTACH_ILLEGAL\x10\x03\x12\x14\n\x10USER_NOT_IN_ROOM\x10\x04\x12\x10\n\x0cSERVER_ERROR\x10\x05\x12\x19\n\x15REQUEST_PARAM_INVALID\x10\x06\x12#\n\x1fROOM_NOT_EXIST_IN_STATE_MANAGER\x10\x07\x12\x13\n\x0fNEW_LIVE_OPENED\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CsAckErrorCode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CSACKERRORCODE._serialized_start=37
  _CSACKERRORCODE._serialized_end=255
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProfileUserLoginDeviceInfoListResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import UserLoginDeviceInfo_pb2 as UserLoginDeviceInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ProfileUserLoginDeviceInfoListResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Profile\x1a\x19UserLoginDeviceInfo.proto\"w\n&ProfileUserLoginDeviceInfoListResponse\x12M\n\x13userLoginDeviceInfo\x18\x01 \x03(\x0b\x32\x30.AcFunDanmu.Im.Cloud.Profile.UserLoginDeviceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ProfileUserLoginDeviceInfoListResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROFILEUSERLOGINDEVICEINFOLISTRESPONSE._serialized_start=104
  _PROFILEUSERLOGINDEVICEINFOLISTRESPONSE._serialized_end=223
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImcVoiceCallRoomInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallStatus_pb2 as CallStatus__pb2
import CallType_pb2 as CallType__pb2
import ChatMode_pb2 as ChatMode__pb2
import ChatTarget_pb2 as ChatTarget__pb2
import User_pb2 as User__pb2
import VoiceCallUserStatus_pb2 as VoiceCallUserStatus__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aImcVoiceCallRoomInfo.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\x10\x43\x61llStatus.proto\x1a\x0e\x43\x61llType.proto\x1a\x0e\x43hatMode.proto\x1a\x10\x43hatTarget.proto\x1a\nUser.proto\x1a\x19VoiceCallUserStatus.proto\"\xde\x04\n\x14ImcVoiceCallRoomInfo\x12\x0e\n\x06roomId\x18\x01 \x01(\t\x12+\n\x08\x66romUser\x18\x02 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x35\n\nchatTarget\x18\x03 \x01(\x0b\x32!.AcFunDanmu.Im.Message.ChatTarget\x12\x0e\n\x06\x63\x61llId\x18\x04 \x01(\t\x12\x14\n\x0cmessageSeqId\x18\x05 \x01(\x03\x12:\n\x08\x63\x61llType\x18\x06 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.CallType\x12>\n\ncallStatus\x18\x07 \x01(\x0e\x32*.AcFunDanmu.Im.Cloud.Voice.Call.CallStatus\x12:\n\x08\x63hatMode\x18\x08 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.ChatMode\x12\x18\n\x10roomCreateTimeMs\x18\t \x01(\x03\x12\x1c\n\x14voiceCallStartTimeMs\x18\n \x01(\x03\x12\x1a\n\x12voiceCallEndTimeMs\x18\x0b \x01(\x03\x12\r\n\x05\x65xtra\x18\x0c \x01(\x0c\x12\'\n\x04host\x18\x15 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\r\n\x05title\x18\x16 \x01(\t\x12G\n\nuserStatus\x18\x17 \x03(\x0b\x32\x33.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallUserStatus\x12\x10\n\x08maxCount\x18\x18 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ImcVoiceCallRoomInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMCVOICECALLROOMINFO._serialized_start=170
  _IMCVOICECALLROOMINFO._serialized_end=776
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VoiceCallRequestEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallType_pb2 as CallType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bVoiceCallRequestEvent.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\x0e\x43\x61llType.proto\"S\n\x15VoiceCallRequestEvent\x12:\n\x08\x63\x61llType\x18\x01 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.CallTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VoiceCallRequestEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VOICECALLREQUESTEVENT._serialized_start=79
  _VOICECALLREQUESTEVENT._serialized_end=162
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserActionInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2
import UserAction_pb2 as UserAction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14UserActionInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Channel\x1a\nUser.proto\x1a\x10UserAction.proto\"\x85\x01\n\x0eUserActionInfo\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x37\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\'.AcFunDanmu.Im.Cloud.Channel.UserAction\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserActionInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERACTIONINFO._serialized_start=84
  _USERACTIONINFO._serialized_end=217
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LiveFeatureState.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16LiveFeatureState.proto\x12\nAcFunDanmu\"\x9d\x02\n\x10LiveFeatureState\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.AcFunDanmu.LiveFeatureState.FeatureType\x12\x38\n\x05state\x18\x02 \x01(\x0e\x32).AcFunDanmu.LiveFeatureState.FeatureState\"9\n\x0b\x46\x65\x61tureType\x12\x13\n\x0f\x46\x45\x41TURE_UNKNOWN\x10\x00\x12\x15\n\x11LANDSCAPE_COMMENT\x10\x01\"\\\n\x0c\x46\x65\x61tureState\x12\x19\n\x15\x46\x45\x41TURE_STATE_UNKNOWN\x10\x00\x12\x17\n\x13\x46\x45\x41TURE_STATE_OPEND\x10\x01\x12\x18\n\x14\x46\x45\x41TURE_STATE_CLOSED\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'LiveFeatureState_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIVEFEATURESTATE._serialized_start=39
  _LIVEFEATURESTATE._serialized_end=324
  _LIVEFEATURESTATE_FEATURETYPE._serialized_start=173
  _LIVEFEATURESTATE_FEATURETYPE._serialized_end=230
  _LIVEFEATURESTATE_FEATURESTATE._serialized_start=232
  _LIVEFEATURESTATE_FEATURESTATE._serialized_end=324
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KeepAliveRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import PushServiceToken_pb2 as PushServiceToken__pb2
import RegisterRequest_pb2 as RegisterRequest__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16KeepAliveRequest.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\x16PushServiceToken.proto\x1a\x15RegisterRequest.proto\"\xe6\x02\n\x10KeepAliveRequest\x12K\n\x0epresenceStatus\x18\x01 \x01(\x0e\x32\x33.AcFunDanmu.Im.Basic.RegisterRequest.PresenceStatus\x12J\n\x0f\x61ppActiveStatus\x18\x02 \x01(\x0e\x32\x31.AcFunDanmu.Im.Basic.RegisterRequest.ActiveStatus\x12?\n\x10pushServiceToken\x18\x03 \x01(\x0b\x32%.AcFunDanmu.Im.Basic.PushServiceToken\x12\x43\n\x14pushServiceTokenList\x18\x04 \x03(\x0b\x32%.AcFunDanmu.Im.Basic.PushServiceToken\x12\x1c\n\x14keepaliveIntervalSec\x18\x05 \x01(\x05\x12\x15\n\ripv6Available\x18\x06 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'KeepAliveRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KEEPALIVEREQUEST._serialized_start=95
  _KEEPALIVEREQUEST._serialized_end=453
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderCreateRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTarget_pb2 as ChatTarget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n SessionFolderCreateRequest.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\x10\x43hatTarget.proto\"\x81\x01\n\x1aSessionFolderCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65xtra\x18\x02 \x01(\x0c\x12\x0f\n\x07iconUrl\x18\x03 \x01(\t\x12\x35\n\nchatTarget\x18\x04 \x03(\x0b\x32!.AcFunDanmu.Im.Message.ChatTargetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderCreateRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERCREATEREQUEST._serialized_start=90
  _SESSIONFOLDERCREATEREQUEST._serialized_end=219
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatSession.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTargetType_pb2 as ChatTargetType__pb2
import Message_pb2 as Message__pb2
import MessageReceiveStatus_pb2 as MessageReceiveStatus__pb2
import RemindBody_pb2 as RemindBody__pb2
import SessionStatus_pb2 as SessionStatus__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x43hatSession.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x14\x43hatTargetType.proto\x1a\rMessage.proto\x1a\x1aMessageReceiveStatus.proto\x1a\x10RemindBody.proto\x1a\x13SessionStatus.proto\x1a\nUser.proto\"\xd0\x05\n\x0b\x43hatSession\x12)\n\x06target\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08maxSeqId\x18\x02 \x01(\x03\x12\x11\n\treadSeqId\x18\x03 \x01(\x03\x12\x16\n\x0eunreadMsgCount\x18\x04 \x01(\x05\x12\x35\n\rlatestMessage\x18\x05 \x03(\x0b\x32\x1e.AcFunDanmu.Im.Message.Message\x12=\n\x0e\x63hatTargetType\x18\x08 \x01(\x0e\x32%.AcFunDanmu.Im.Message.ChatTargetType\x12\x10\n\x08targetId\x18\t \x01(\x03\x12\x12\n\nactiveTime\x18\n \x01(\x03\x12\x10\n\x08priority\x18\x0b \x01(\x05\x12\x12\n\ncategoryId\x18\x0c \x01(\x05\x12\x0e\n\x06\x63ursor\x18\r \x01(\t\x12\x13\n\x0b\x61\x63\x63ountType\x18\x0e \x01(\x05\x12\x18\n\x10\x61ggregateSession\x18\x0f \x01(\x08\x12\x16\n\x0ejumpCategoryId\x18\x10 \x01(\x05\x12\x10\n\x08\x65xpireAt\x18\x11 \x01(\x03\x12\x15\n\reffectiveFrom\x18\x12 \x01(\x03\x12\x13\n\x0bstrTargetId\x18\x13 \x01(\t\x12\x35\n\nremindBody\x18\x14 \x03(\x0b\x32!.AcFunDanmu.Im.Message.RemindBody\x12\x17\n\x0ftargetReadSeqId\x18\x15 \x01(\x03\x12\x0c\n\x04mute\x18\x16 \x01(\x08\x12\x34\n\x06status\x18\x17 \x01(\x0e\x32$.AcFunDanmu.Im.Message.SessionStatus\x12I\n\x14messageReceiveStatus\x18\x18 \x01(\x0e\x32+.AcFunDanmu.Im.Message.MessageReceiveStatus\x12\r\n\x05\x65xtra\x18\x19 \x01(\x0c\x12\x14\n\x0cmarkedUnread\x18\x1a \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChatSession_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHATSESSION._serialized_start=161
  _CHATSESSION._serialized_end=881
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LocaleMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LocaleMessage.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xa0\x01\n\rLocaleMessage\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12J\n\x0c\x65rrorMessage\x18\x02 \x03(\x0b\x32\x34.AcFunDanmu.Im.Basic.LocaleMessage.ErrorMessageEntry\x1a\x33\n\x11\x45rrorMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'LocaleMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOCALEMESSAGE_ERRORMESSAGEENTRY._options = None
  _LOCALEMESSAGE_ERRORMESSAGEENTRY._serialized_options = b'8\001'
  _LOCALEMESSAGE._serialized_start=45
  _LOCALEMESSAGE._serialized_end=205
  _LOCALEMESSAGE_ERRORMESSAGEENTRY._serialized_start=154
  _LOCALEMESSAGE_ERRORMESSAGEENTRY._serialized_end=205
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalChatEnd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x43ommonStateSignalChatEnd.proto\x12\nAcFunDanmu\"\xaa\x03\n\x18\x43ommonStateSignalChatEnd\x12\x0e\n\x06\x63hatId\x18\x01 \x01(\t\x12=\n\x07\x65ndType\x18\x02 \x01(\x0e\x32,.AcFunDanmu.CommonStateSignalChatEnd.EndType\x12:\n\x01\x63\x18\x03 \x01(\x0b\x32/.AcFunDanmu.CommonStateSignalChatEnd.BannedInfo\x1a\x38\n\nBannedInfo\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\t\x12\t\n\x01\x63\x18\x03 \x01(\t\x12\t\n\x01\x64\x18\x04 \x01(\t\"\xc8\x01\n\x07\x45ndType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10\x43\x41NCEL_BY_AUTHOR\x10\x01\x12\x11\n\rEND_BY_AUTHOR\x10\x02\x12\x10\n\x0c\x45ND_BY_GUEST\x10\x03\x12\x10\n\x0cGUEST_REJECT\x10\x04\x12\x11\n\rGUEST_TIMEOUT\x10\x05\x12\x1b\n\x17GUEST_HEARTBEAT_TIMEOUT\x10\x06\x12\x1c\n\x18\x41UTHOR_HEARTBEAT_TIMEOUT\x10\x07\x12\x15\n\x11PEER_LIVE_STOPPED\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalChatEnd_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALCHATEND._serialized_start=47
  _COMMONSTATESIGNALCHATEND._serialized_end=473
  _COMMONSTATESIGNALCHATEND_BANNEDINFO._serialized_start=214
  _COMMONSTATESIGNALCHATEND_BANNEDINFO._serialized_end=270
  _COMMONSTATESIGNALCHATEND_ENDTYPE._serialized_start=273
  _COMMONSTATESIGNALCHATEND_ENDTYPE._serialized_end=473
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderUpdateRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n SessionFolderUpdateRequest.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\"\x91\x02\n\x1aSessionFolderUpdateRequest\x12\x17\n\x0fsessionFolderId\x18\x01 \x01(\t\x12Y\n\x06\x66ields\x18\x02 \x03(\x0e\x32I.AcFunDanmu.Im.Cloud.SessionFolder.SessionFolderUpdateRequest.UpdateField\x12\x12\n\nfolderName\x18\x03 \x01(\t\x12\x0f\n\x07iconUrl\x18\x04 \x01(\t\x12\r\n\x05\x65xtra\x18\x05 \x01(\x0c\"K\n\x0bUpdateField\x12\x12\n\x0eUN_KNOWN_FIELD\x10\x00\x12\x0f\n\x0b\x46OLDER_NAME\x10\x01\x12\x0c\n\x08ICON_URL\x10\x02\x12\t\n\x05\x45XTRA\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderUpdateRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERUPDATEREQUEST._serialized_start=72
  _SESSIONFOLDERUPDATEREQUEST._serialized_end=345
  _SESSIONFOLDERUPDATEREQUEST_UPDATEFIELD._serialized_start=270
  _SESSIONFOLDERUPDATEREQUEST_UPDATEFIELD._serialized_end=345
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LinkErrorCode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LinkErrorCode.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic*\xcd\x07\n\rLinkErrorCode\x12\x08\n\x04SUCC\x10\x00\x12\x0e\n\tBASIC_MIN\x10\x90N\x12\x13\n\x0eINTERNEL_ERROR\x10\x91N\x12\x18\n\x13SERVICE_UNAVAILABLE\x10\x92N\x12\x14\n\x0fSERVICE_TIMEOUT\x10\x93N\x12\x12\n\rINVALID_TOKEN\x10\x94N\x12\x1e\n\x19REG_ENCYRPT_WITHOUT_TOKEN\x10\x95N\x12\x16\n\x11PARSE_PB_HDR_FAIL\x10\x96N\x12\x16\n\x11PARSE_PB_PLD_FAIL\x10\x97N\x12\x12\n\rPARSE_PB_FAIL\x10\x98N\x12\x15\n\x10\x44\x45\x43ODED_LEN_FAIL\x10\x99N\x12\x10\n\x0bINVALID_KEY\x10\x9aN\x12\x11\n\x0c\x45NCRYPT_FAIL\x10\x9bN\x12\x11\n\x0c\x44\x45\x43RYPT_FAIL\x10\x9cN\x12\x10\n\x0bINVALID_TAG\x10\x9dN\x12\x10\n\x0bINVALID_VER\x10\x9eN\x12\x1a\n\x15INVALID_COMPRESS_TYPE\x10\xa0N\x12\x19\n\x14INVALID_ENCRYPT_TYPE\x10\xa1N\x12\x11\n\x0cNOT_REGISTER\x10\xa2N\x12\x14\n\x0fUSER_NOT_ONLINE\x10\xa3N\x12\x14\n\x0fINVALID_COMMAND\x10\xa4N\x12\x1a\n\x15PUSH_UNREGISTER_ERROR\x10\xa5N\x12\x10\n\x0bINVALID_SID\x10\xa6N\x12\x18\n\x13INVALID_INSTANCE_ID\x10\xa7N\x12\x1c\n\x17\x43LIENT_LOCALE_NOT_MATCH\x10\xa8N\x12#\n\x1eINVALID_TOKEN_PASSWORD_CHANGED\x10\xa9N\x12 \n\x1bINVALID_TOKEN_TOKEN_EXPIRED\x10\xaaN\x12$\n\x1fINVALID_TOKEN_TOKEN_VALUE_ERROR\x10\xabN\x12(\n#INVALID_TOKEN_LOGIN_ON_OTHER_DEVICE\x10\xacN\x12\x14\n\x0f\x46ORCE_RECONNECT\x10\xadN\x12\x13\n\x0e\x43LIENT_TIMEOUT\x10\xaeN\x12\x15\n\x10INVALID_ARGUMENT\x10\xafN\x12\x19\n\x14INVALID_FORMAT_TOKEN\x10\xb0N\x12\x12\n\rEMPTY_PAYLOAD\x10\xb1N\x12\x12\n\rCOMPRESS_FAIL\x10\xb2N\x12\x14\n\x0f\x44\x45\x43OMPRESS_FAIL\x10\xb3N\x12\x11\n\x0cOUT_OF_ORDER\x10\xb4N\x12\x11\n\x0cOUT_OF_LIMIT\x10\xb5N\x12\x16\n\x11TOO_LARGE_PAYLOAD\x10\xb6N\x12\x15\n\x10\x41NONYMOUSE_ERROR\x10\xb7N\x12\x0f\n\tBASIC_MAX\x10\x9f\x9c\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'LinkErrorCode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LINKERRORCODE._serialized_start=45
  _LINKERRORCODE._serialized_end=1018
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TokenInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fTokenInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\x85\x01\n\tTokenInfo\x12;\n\ttokenType\x18\x01 \x01(\x0e\x32(.AcFunDanmu.Im.Basic.TokenInfo.TokenType\x12\r\n\x05token\x18\x02 \x01(\x0c\",\n\tTokenType\x12\x0c\n\x08kInvalid\x10\x00\x12\x11\n\rkServiceToken\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'TokenInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOKENINFO._serialized_start=41
  _TOKENINFO._serialized_end=174
  _TOKENINFO_TOKENTYPE._serialized_start=130
  _TOKENINFO_TOKENTYPE._serialized_end=174
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonNotifySignalLiveManagerState.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(CommonNotifySignalLiveManagerState.proto\x12\nAcFunDanmu\"\xd3\x01\n\"CommonNotifySignalLiveManagerState\x12J\n\x05state\x18\x01 \x01(\x0e\x32;.AcFunDanmu.CommonNotifySignalLiveManagerState.ManagerState\"a\n\x0cManagerState\x12\x19\n\x15MANAGER_STATE_UNKNOWN\x10\x00\x12\x11\n\rMANAGER_ADDED\x10\x01\x12\x13\n\x0fMANAGER_REMOVED\x10\x02\x12\x0e\n\nIS_MANAGER\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonNotifySignalLiveManagerState_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONNOTIFYSIGNALLIVEMANAGERSTATE._serialized_start=57
  _COMMONNOTIFYSIGNALLIVEMANAGERSTATE._serialized_end=268
  _COMMONNOTIFYSIGNALLIVEMANAGERSTATE_MANAGERSTATE._serialized_start=171
  _COMMONNOTIFYSIGNALLIVEMANAGERSTATE_MANAGERSTATE._serialized_end=268
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: acfun.live.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61\x63\x66un.live.proto\x12\nAcFunDanmu\"-\n\rAcFunUserInfo\x12\x0e\n\x06userId\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x1c\x41\x63\x66unActionSignalThrowBanana\x12*\n\x07visitor\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.AcFunUserInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x12\n\nsendTimeMs\x18\x03 \x01(\x03\"2\n\x1b\x41\x63\x66unStateSignalDisplayInfo\x12\x13\n\x0b\x62\x61nanaCount\x18\x01 \x01(\t\"\x89\x01\n\x19\x41\x63\x66unActionSignalJoinClub\x12+\n\x08\x66\x61nsInfo\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.AcFunUserInfo\x12+\n\x08uperInfo\x18\x02 \x01(\x0b\x32\x19.AcFunDanmu.AcFunUserInfo\x12\x12\n\njoinTimeMs\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'acfun_live_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACFUNUSERINFO._serialized_start=32
  _ACFUNUSERINFO._serialized_end=77
  _ACFUNACTIONSIGNALTHROWBANANA._serialized_start=79
  _ACFUNACTIONSIGNALTHROWBANANA._serialized_end=188
  _ACFUNSTATESIGNALDISPLAYINFO._serialized_start=190
  _ACFUNSTATESIGNALDISPLAYINFO._serialized_end=240
  _ACFUNACTIONSIGNALJOINCLUB._serialized_start=243
  _ACFUNACTIONSIGNALJOINCLUB._serialized_end=380
# @@protoc_insertion_point(module_scope)



# coding=utf-8
import time
import json
import base64

__author__ = 'dolacmeo'

message_types = {
    "ZtLiveScActionSignal":  "(粉丝互动)",
    "ZtLiveScStateSignal":   "(数据更新)",
    "ZtLiveScNotifySignal":  "(房管来啦)",
    "ZtLiveScStatusChanged": "(状态变更)",
    "ZtLiveScTicketInvalid": "(连接失效)[需要重连]",
}

signal_types = {
    "CommonActionSignalComment":                    "[送出弹幕]",
    "CommonActionSignalLike":                       "[爱心点赞]",
    "CommonActionSignalUserEnterRoom":              "[进入房间]",
    "CommonActionSignalUserFollowAuthor":           "[关注主播]",
    "AcfunActionSignalThrowBanana":                 "[投喂香蕉]",
    "CommonActionSignalGift":                       "[送出礼物]",
    "CommonActionSignalRichText":                   "[高级弹幕]",
    "AcfunActionSignalJoinClub":                    "[加守护团]",
    "AcfunStateSignalDisplayInfo":                  "[香蕉总数]",
    "CommonStateSignalDisplayInfo":                 "[在线人数][点赞数量]",
    "CommonStateSignalTopUsers":                    "[前三粉丝]",
    "CommonStateSignalRecentComment":               "[近期弹幕]",
    "CommonStateSignalChatCall":                    "[连麦被叫呼叫]",
    "CommonStateSignalChatAccept":                  "[连麦被叫接受]",
    "CommonStateSignalChatReady":                   "[连麦被叫等待]",
    "CommonStateSignalChatEnd":                     "[连麦被叫结束]",
    "CommonStateSignalCurrentRedpackList":          "[红包榜单]",
    "CommonStateSignalAuthorChatCall":              "[连麦主叫呼叫]",
    "CommonStateSignalAuthorChatAccept":            "[连麦主叫接受]",
    "CommonStateSignalAuthorChatReady":             "[连麦主叫等待]",
    "CommonStateSignalAuthorChatEnd":               "[连麦主叫结束]",
    "CommonStateSignalAuthorChatChangeSoundConfig": "[连麦主叫导播]",
    "CommonStateSignalPKAccept":                    "[连麦挑战接受]",
    "CommonStateSignalPKInvitation":                "[连麦挑战邀请]",
    "CommonStateSignalPKReady":                     "[连麦挑战等待]",
    "CommonStateSignalPKSoundConfigChanged":        "[连麦挑战导播]",
    "CommonStateSignalPkEnd":                       "[连麦挑战结束]",
    "CommonStateSignalPkStatistic":                 "[连麦挑战统计]",
    "CommonStateSignalWishSheetCurrentState":       "[愿望列表状态]",
    "CommonNotifySignalKickedOut":                  "[踢出房间]",
    "CommonNotifySignalViolationAlert":             "[违规警告]",
    "CommonNotifySignalLiveManagerState":           "[房管状态]",
}

signal_decodes = {
    "CommonActionSignalComment":            "💬{content}",
    "CommonStateSignalRecentComment":       "🗨️{content}",
    "CommonActionSignalLike":               "💕点赞了",
    "CommonActionSignalUserEnterRoom":      "🎟️进入直播间",
    "CommonActionSignalUserFollowAuthor":   "👀关注了主播",
    "AcfunActionSignalJoinClub":            "👥加入守护团",
    "AcfunActionSignalThrowBanana":         "🍌给主播投蕉",
    "CommonActionSignalGift":               "🎁送出{batchSize}个[{giftName}]"
}


def uint8_payload_to_base64(data: dict):
    """
    用于反解网页中等待encode的payload
    进入页面: https://message.acfun.cn/im
    调试js  : https://static.yximgs.com/udata/pkg/acfun-im/ImSdk.b0aeed.js
    进入页面: https://live.acfun.cn/live/
    设置断点: 9145  => e.payloadData
    调试js  : https://ali-imgs.acfun.cn/kos/nlav10360/static/js/3.867c7c46.js
    设置断点: 40910 => t
    return: base64encoded ==> https://protogen.marcgravell.com/decode
    """
    b_str = b''
    for x in range(len(data.keys())):
        b_str += bytes([data[str(x)]])
    return base64.standard_b64encode(b_str)


class AcLiveReader:
    temps = list()
    message_bans = list()
    gift_data = None
    filters = None
    config = dict()
    status = dict()
    notices = list()
    output_default = "{message}{signal}{time}{user}{content}"

    def __init__(self, /, **config):
        self.config = config
        self.filters = config.get("filters")
        self.gift_data = config.get("gift", {})

    def __call__(self, data: list):
        self.recv(data)
        return self.output()

    def recv(self, data: list):
        for item in data:
            # print(f"{item=}")
            signal_path = item['signal']
            if item['signal'].count(".") == 0:
                signal_path += "."
            msg_type, signal_name = signal_path.split(".")
            data_package = (msg_type, signal_name, item.get('payload'))
            if isinstance(self.filters, dict):
                if msg_type not in self.filters.get("mtype", []) or \
                        signal_name not in self.filters.get("signal", []):
                    # print(f"{msg_type=},{signal_name=}")
                    continue
            if signal_name in signal_decodes:
                self.decode(*data_package)
            elif "StateSignal" in signal_name:
                self._room_status(*data_package)
            elif "Notify" in signal_name:
                self._notify(*data_package)

    def output(self):
        # "message", "signal", "time", "user", "content"
        display = self.config.get("output_temp", self.output_default)
        if display is None:
            display = self.output_default
        result = list()
        for item in self.temps:
            result.append(display.format(**item))
        self.temps = list()
        return result

    @staticmethod
    def _user_info(data, id_only: bool = False):
        if data is None:
            return ""
        if id_only is True:
            return data['userId']
        base = f"<{data['userId']}@{data['nickname']}>"
        if 'badge' in data:
            badge = json.loads(data['badge']).get('medalInfo', {})
            base += f"『{badge['clubName']}|lv{badge['level']}』"
        return base

    @staticmethod
    def _unix2string(t: (int, float, str), f: str = "%H:%M:%S"):
        if len(str(t)) > 10:
            t = int(str(t)[:10])
        return time.strftime(f, time.localtime(t))

    def _room_status(self, mtype, signal, payload):
        if signal in ["AcfunStateSignalDisplayInfo", "CommonStateSignalDisplayInfo"]:
            keys = ["bananaCount", "watchingCount", "likeCount"]
            for x in keys:
                if x in payload:
                    self.status[x] = payload[x]
        elif signal in ["CommonStateSignalTopUsers"]:
            self.status["topUsers"] = payload['user']
        return True

    def _notify(self, mtype, signal, payload):
        keys = ["reason", "violationContent", "state"]
        for x in keys:
            if x in payload:
                self.notices.append(payload[x])
        return True

    def decode(self, mtype, signal, payload):
        if isinstance(payload, dict):
            if ["comment"] == list(payload.keys()):
                payload = payload.get("comment", [])
        for item in payload:
            sname = signal
            if self.config.get("type_name", True):
                mtype = message_types.get(mtype)
                sname = signal_types.get(signal)
            stime = item.get("sendTimeMs")
            if self.config.get("time_tans", True) is True:
                stime = self._unix2string(stime)
            user = self._user_info(item.get("userInfo"), self.config.get("userid_only", False))
            content = signal_decodes.get(signal)
            if "content" in item:
                content = content.format(content=item.get("content"))
            elif signal == "CommonActionSignalGift":
                gift_name = f"{item.get('giftId')}"
                if isinstance(self.gift_data, dict):
                    gift_name = self.gift_data.get(gift_name, {}).get("giftName", "UNKNOWN")
                content = content.format(batchSize=item.get("batchSize"), giftName=gift_name)
                if item["comboCount"] > 1:
                    content += f" 连击{item['comboCount']}"
            elif signal == "CommonActionSignalRichText":
                print(item)
            self.temps.append(dict(zip(
                ["message", "signal", "time", "user", "content"],
                [mtype, sname, stime, user, content]
            )))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CallStatus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x43\x61llStatus.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call*{\n\nCallStatus\x12\x0e\n\nCS_UNKNOWN\x10\x00\x12\x0b\n\x07WAITING\x10\x01\x12\x0b\n\x07\x43\x41LLING\x10\x02\x12\x0c\n\x08REJECTED\x10\x03\x12\x0c\n\x08\x46INISHED\x10\x04\x12\r\n\tCANCELLED\x10\x05\x12\x0b\n\x07TIMEOUT\x10\x06\x12\x0b\n\x07\x42USYING\x10\x07\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CallStatus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CALLSTATUS._serialized_start=52
  _CALLSTATUS._serialized_end=175
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VoiceCallMessageContent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallStatus_pb2 as CallStatus__pb2
import CallType_pb2 as CallType__pb2
import ChatMode_pb2 as ChatMode__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dVoiceCallMessageContent.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x10\x43\x61llStatus.proto\x1a\x0e\x43\x61llType.proto\x1a\x0e\x43hatMode.proto\x1a\nUser.proto\"\xac\x03\n\x17VoiceCallMessageContent\x12\x0e\n\x06roomId\x18\x01 \x01(\t\x12:\n\x08\x63\x61llType\x18\x02 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.CallType\x12:\n\x06status\x18\x03 \x01(\x0e\x32*.AcFunDanmu.Im.Cloud.Voice.Call.CallStatus\x12\x13\n\x0bstartTimeMs\x18\x04 \x01(\x03\x12\x11\n\tendTimeMs\x18\x05 \x01(\x03\x12+\n\x08\x66romUser\x18\x06 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12:\n\x08\x63hatMode\x18\x07 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.ChatMode\x12\r\n\x05title\x18\x15 \x01(\t\x12\'\n\x04host\x18\x16 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12.\n\x0bparticipant\x18\x17 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08maxCount\x18\x18 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VoiceCallMessageContent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VOICECALLMESSAGECONTENT._serialized_start=125
  _VOICECALLMESSAGECONTENT._serialized_end=553
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DeviceInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x44\x65viceInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xa2\x03\n\nDeviceInfo\x12\x42\n\x0cplatformType\x18\x01 \x01(\x0e\x32,.AcFunDanmu.Im.Basic.DeviceInfo.PlatformType\x12\x11\n\tosVersion\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65viceModel\x18\x03 \x01(\t\x12\x0f\n\x07imeiMd5\x18\x04 \x01(\x0c\x12\x10\n\x08\x64\x65viceId\x18\x05 \x01(\t\x12\x0f\n\x07softDid\x18\x06 \x01(\t\x12\x0f\n\x07kwaiDid\x18\x07 \x01(\t\x12\x14\n\x0cmanufacturer\x18\x08 \x01(\t\x12\x12\n\ndeviceName\x18\t \x01(\t\"\xb8\x01\n\x0cPlatformType\x12\x0c\n\x08kInvalid\x10\x00\x12\x0c\n\x08kAndroid\x10\x01\x12\x08\n\x04kiOS\x10\x02\x12\x0c\n\x08kWindows\x10\x03\x12\x12\n\x0eWECHAT_ANDROID\x10\x04\x12\x0e\n\nWECHAT_IOS\x10\x05\x12\x06\n\x02H5\x10\x06\x12\x0e\n\nH5_ANDROID\x10\x07\x12\n\n\x06H5_IOS\x10\x08\x12\x0e\n\nH5_WINDOWS\x10\t\x12\n\n\x06H5_MAC\x10\n\x12\x10\n\x0ckPlatformNum\x10\x0b\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DeviceInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEVICEINFO._serialized_start=42
  _DEVICEINFO._serialized_end=460
  _DEVICEINFO_PLATFORMTYPE._serialized_start=276
  _DEVICEINFO_PLATFORMTYPE._serialized_end=460
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalAuthorChatEnd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$CommonStateSignalAuthorChatEnd.proto\x12\nAcFunDanmu\"\xe4\x02\n\x1e\x43ommonStateSignalAuthorChatEnd\x12\x14\n\x0c\x61uthorChatId\x18\x01 \x01(\t\x12\x43\n\x07\x65ndType\x18\x02 \x01(\x0e\x32\x32.AcFunDanmu.CommonStateSignalAuthorChatEnd.EndType\x12\x11\n\tendLiveId\x18\x03 \x01(\t\"\xd3\x01\n\x07\x45ndType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x15\n\x11\x43\x41NCEL_BY_INVITER\x10\x01\x12\x12\n\x0e\x45ND_BY_INVITER\x10\x02\x12\x12\n\x0e\x45ND_BY_INVITEE\x10\x03\x12\x12\n\x0eINVITEE_REJECT\x10\x04\x12\x13\n\x0fINVITEE_TIMEOUT\x10\x05\x12\x1d\n\x19INVITEE_HEARTBEAT_TIMEOUT\x10\x06\x12\x1d\n\x19INVITER_HEARTBEAT_TIMEOUT\x10\x07\x12\x15\n\x11PEER_LIVE_STOPPED\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalAuthorChatEnd_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALAUTHORCHATEND._serialized_start=53
  _COMMONSTATESIGNALAUTHORCHATEND._serialized_end=409
  _COMMONSTATESIGNALAUTHORCHATEND_ENDTYPE._serialized_start=198
  _COMMONSTATESIGNALAUTHORCHATEND_ENDTYPE._serialized_end=409
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveScStateSignal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveStateSignalItem_pb2 as ZtLiveStateSignalItem__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ZtLiveScStateSignal.proto\x12\nAcFunDanmu\x1a\x1bZtLiveStateSignalItem.proto\"F\n\x13ZtLiveScStateSignal\x12/\n\x04item\x18\x01 \x03(\x0b\x32!.AcFunDanmu.ZtLiveStateSignalItemb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveScStateSignal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVESCSTATESIGNAL._serialized_start=70
  _ZTLIVESCSTATESIGNAL._serialized_end=140
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CMessageReceiptCountGetRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&B2CMessageReceiptCountGetRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"F\n B2CMessageReceiptCountGetRequest\x12\r\n\x05seqId\x18\x01 \x03(\x03\x12\x13\n\x0bstrTargetId\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CMessageReceiptCountGetRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CMESSAGERECEIPTCOUNTGETREQUEST._serialized_start=65
  _B2CMESSAGERECEIPTCOUNTGETREQUEST._serialized_end=135
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalTopUsers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x43ommonStateSignalTopUsers.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\"\xe4\x01\n\x19\x43ommonStateSignalTopUsers\x12;\n\x04user\x18\x01 \x03(\x0b\x32-.AcFunDanmu.CommonStateSignalTopUsers.TopUser\x1a\x89\x01\n\x07TopUser\x12,\n\x08userInfo\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12\x1e\n\x16\x63ustomWatchingListData\x18\x03 \x01(\t\x12\x19\n\x11\x64isplaySendAmount\x18\x04 \x01(\t\x12\x15\n\ranonymousUser\x18\x05 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalTopUsers_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALTOPUSERS._serialized_start=70
  _COMMONSTATESIGNALTOPUSERS._serialized_end=298
  _COMMONSTATESIGNALTOPUSERS_TOPUSER._serialized_start=161
  _COMMONSTATESIGNALTOPUSERS_TOPUSER._serialized_end=298
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AppInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rAppInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xe9\x01\n\x07\x41ppInfo\x12\x0f\n\x07\x61ppName\x18\x01 \x01(\t\x12\x12\n\nappVersion\x18\x02 \x01(\t\x12\x12\n\nappChannel\x18\x03 \x01(\t\x12\x12\n\nsdkVersion\x18\x04 \x01(\t\x12\x13\n\x0blinkVersion\x18\x05 \x01(\t\x12\x46\n\rextensionInfo\x18\x0b \x03(\x0b\x32/.AcFunDanmu.Im.Basic.AppInfo.ExtensionInfoEntry\x1a\x34\n\x12\x45xtensionInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AppInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPINFO_EXTENSIONINFOENTRY._options = None
  _APPINFO_EXTENSIONINFOENTRY._serialized_options = b'8\001'
  _APPINFO._serialized_start=39
  _APPINFO._serialized_end=272
  _APPINFO_EXTENSIONINFOENTRY._serialized_start=220
  _APPINFO_EXTENSIONINFOENTRY._serialized_end=272
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionListRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SyncCookie_pb2 as SyncCookie__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18SessionListRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x10SyncCookie.proto\"v\n\x12SessionListRequest\x12\x33\n\nsyncCookie\x18\x01 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.SyncCookie\x12\x12\n\ncategoryId\x18\x02 \x01(\x05\x12\x17\n\x0flocalDataStatus\x18\x03 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionListRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONLISTREQUEST._serialized_start=69
  _SESSIONLISTREQUEST._serialized_end=187
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PingResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12PingResponse.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"w\n\x0cPingResponse\x12\x17\n\x0fserverTimestamp\x18\x01 \x01(\x0f\x12\x10\n\x08\x63lientIp\x18\x02 \x01(\x07\x12\x12\n\nredirectIp\x18\x03 \x01(\x07\x12\x14\n\x0credirectPort\x18\x04 \x01(\r\x12\x12\n\nclientIpV6\x18\x05 \x01(\x0c\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PingResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PINGRESPONSE._serialized_start=43
  _PINGRESPONSE._serialized_end=162
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RegisterRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AppInfo_pb2 as AppInfo__pb2
import DeviceInfo_pb2 as DeviceInfo__pb2
import EnvInfo_pb2 as EnvInfo__pb2
import PushServiceToken_pb2 as PushServiceToken__pb2
import ZtCommonInfo_pb2 as ZtCommonInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15RegisterRequest.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\rAppInfo.proto\x1a\x10\x44\x65viceInfo.proto\x1a\rEnvInfo.proto\x1a\x16PushServiceToken.proto\x1a\x12ZtCommonInfo.proto\"\xe5\x05\n\x0fRegisterRequest\x12-\n\x07\x61ppInfo\x18\x01 \x01(\x0b\x32\x1c.AcFunDanmu.Im.Basic.AppInfo\x12\x33\n\ndeviceInfo\x18\x02 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.DeviceInfo\x12-\n\x07\x65nvInfo\x18\x03 \x01(\x0b\x32\x1c.AcFunDanmu.Im.Basic.EnvInfo\x12K\n\x0epresenceStatus\x18\x04 \x01(\x0e\x32\x33.AcFunDanmu.Im.Basic.RegisterRequest.PresenceStatus\x12J\n\x0f\x61ppActiveStatus\x18\x05 \x01(\x0e\x32\x31.AcFunDanmu.Im.Basic.RegisterRequest.ActiveStatus\x12\x17\n\x0f\x61ppCustomStatus\x18\x06 \x01(\x0c\x12?\n\x10pushServiceToken\x18\x07 \x01(\x0b\x32%.AcFunDanmu.Im.Basic.PushServiceToken\x12\x12\n\ninstanceId\x18\x08 \x01(\x03\x12\x43\n\x14pushServiceTokenList\x18\t \x03(\x0b\x32%.AcFunDanmu.Im.Basic.PushServiceToken\x12\x1c\n\x14keepaliveIntervalSec\x18\n \x01(\x05\x12\x37\n\x0cztCommonInfo\x18\x0b \x01(\x0b\x32!.AcFunDanmu.Im.Basic.ZtCommonInfo\x12\x15\n\ripv6Available\x18\x0c \x01(\x08\";\n\x0ePresenceStatus\x12\x14\n\x10kPresenceOffline\x10\x00\x12\x13\n\x0fkPresenceOnline\x10\x01\"H\n\x0c\x41\x63tiveStatus\x12\x0c\n\x08kInvalid\x10\x00\x12\x14\n\x10kAppInForeground\x10\x01\x12\x14\n\x10kAppInBackground\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RegisterRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTERREQUEST._serialized_start=139
  _REGISTERREQUEST._serialized_end=880
  _REGISTERREQUEST_PRESENCESTATUS._serialized_start=747
  _REGISTERREQUEST_PRESENCESTATUS._serialized_end=806
  _REGISTERREQUEST_ACTIVESTATUS._serialized_start=808
  _REGISTERREQUEST_ACTIVESTATUS._serialized_end=880
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientConfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ClientStatisticalDataConfig_pb2 as ClientStatisticalDataConfig__pb2
import NetworkQualityDetectionConfig_pb2 as NetworkQualityDetectionConfig__pb2
import SubBizAggregationConfig_pb2 as SubBizAggregationConfig__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x43lientConfig.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Config\x1a!ClientStatisticalDataConfig.proto\x1a#NetworkQualityDetectionConfig.proto\x1a\x1dSubBizAggregationConfig.proto\"\x89\x08\n\x0c\x43lientConfig\x12\x1f\n\x17\x66\x65tchUserStatusInterval\x18\x01 \x01(\x05\x12$\n\x1c\x63hannelUserHeartbeatInterval\x18\x02 \x01(\x05\x12`\n\x1dnetworkQualityDetectionConfig\x18\x03 \x01(\x0b\x32\x39.AcFunDanmu.Im.Cloud.Config.NetworkQualityDetectionConfig\x12#\n\x1binputtingTipDisplayInterval\x18\x04 \x01(\x05\x12 \n\x18\x62\x61tchSendMessageMaxCount\x18\x05 \x01(\x05\x12\x1f\n\x17resourceUploadingDomain\x18\x06 \x01(\t\x12\x1b\n\x13ktpFileLenThreshold\x18\x07 \x01(\x05\x12\x1a\n\x12ktpUploadingDomain\x18\x08 \x01(\t\x12\x1f\n\x17\x63lientSyncMinIntervalMs\x18\t \x01(\x05\x12$\n\x1c\x64ownloadFileMaxLenPerRequest\x18\n \x01(\x05\x12\\\n\x1b\x63lientStatisticalDataConfig\x18\x0b \x01(\x0b\x32\x37.AcFunDanmu.Im.Cloud.Config.ClientStatisticalDataConfig\x12\x1d\n\x15maxMessageBytesLength\x18\x0c \x01(\x05\x12\'\n\x1fsessionDeletionNotOverAllDevice\x18\r \x01(\x08\x12T\n\x17subBizAggregationConfig\x18\x0e \x01(\x0b\x32\x33.AcFunDanmu.Im.Cloud.Config.SubBizAggregationConfig\x12$\n\x1c\x63ountVisibleMessageThreshold\x18\x0f \x01(\x05\x12\x33\n+disableSessionSyncWhenAppSwitchToForeground\x18\x10 \x01(\x08\x12*\n\"maxMessagesPreloadAfterSessionSync\x18\x11 \x01(\x05\x12\x35\n-maxSessionsNeedPreloadMessageAfterSessionSync\x18\x12 \x01(\x05\x12\x15\n\rztImApiDomain\x18\x13 \x01(\t\x12 \n\x18voiceCallTimeoutInterval\x18\x14 \x01(\x05\x12\"\n\x1avoiceCallHeartbeatInterval\x18\x15 \x01(\x05\x12\x18\n\x10\x63lickMessageType\x18\x16 \x03(\x05\x12\x1c\n\x14\x61utoRetryMaxInterval\x18\x17 \x01(\x05\x12\x19\n\x11\x61utoRetryMaxTimes\x18\x18 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ClientConfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLIENTCONFIG._serialized_start=154
  _CLIENTCONFIG._serialized_end=1187
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CsEvaluationMessageContent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n CsEvaluationMessageContent.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\xcd\x03\n\x1a\x43sEvaluationMessageContent\x12\x10\n\x08targetId\x18\x01 \x01(\x03\x12\x62\n\x10\x65valuationOption\x18\x02 \x03(\x0b\x32H.AcFunDanmu.Im.Cloud.Message.CsEvaluationMessageContent.EvaluationOption\x12\r\n\x05title\x18\x03 \x01(\t\x1a\xe7\x01\n\x10\x45valuationOption\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0f\n\x07grayUrl\x18\x02 \x01(\t\x12\x11\n\toptionTxt\x18\x03 \x01(\t\x12\x12\n\noptionType\x18\x04 \x01(\x05\x12\x10\n\x08selected\x18\x05 \x01(\x08\x12j\n\x0fsecondaryOption\x18\x06 \x03(\x0b\x32Q.AcFunDanmu.Im.Cloud.Message.CsEvaluationMessageContent.EvaluationSecondaryOption\x12\x10\n\x08subTitle\x18\x07 \x01(\t\x1a@\n\x19\x45valuationSecondaryOption\x12\x10\n\x08selected\x18\x01 \x01(\x08\x12\x11\n\toptionTxt\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CsEvaluationMessageContent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CSEVALUATIONMESSAGECONTENT._serialized_start=66
  _CSEVALUATIONMESSAGECONTENT._serialized_end=527
  _CSEVALUATIONMESSAGECONTENT_EVALUATIONOPTION._serialized_start=230
  _CSEVALUATIONMESSAGECONTENT_EVALUATIONOPTION._serialized_end=461
  _CSEVALUATIONMESSAGECONTENT_EVALUATIONSECONDARYOPTION._serialized_start=463
  _CSEVALUATIONMESSAGECONTENT_EVALUATIONSECONDARYOPTION._serialized_end=527
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtCommonInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12ZtCommonInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xf4\x01\n\x0cZtCommonInfo\x12\x0b\n\x03kpn\x18\x01 \x01(\t\x12\x0b\n\x03kpf\x18\x02 \x01(\t\x12\x0e\n\x06subBiz\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03\x64id\x18\x05 \x01(\t\x12\x10\n\x08\x63lientIp\x18\x06 \x01(\x03\x12\x0e\n\x06\x61ppVer\x18\x07 \x01(\t\x12\x0b\n\x03ver\x18\x08 \x01(\t\x12\x0b\n\x03lat\x18\t \x01(\t\x12\x0b\n\x03lon\x18\n \x01(\t\x12\x0b\n\x03mod\x18\x0b \x01(\t\x12\x0b\n\x03net\x18\x0c \x01(\t\x12\x0b\n\x03sys\x18\r \x01(\t\x12\t\n\x01\x63\x18\x0e \x01(\t\x12\x10\n\x08language\x18\x0f \x01(\t\x12\x13\n\x0b\x63ountryCode\x18\x10 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtCommonInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTCOMMONINFO._serialized_start=44
  _ZTCOMMONINFO._serialized_end=288
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LeaveSession.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTarget_pb2 as ChatTarget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12LeaveSession.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x10\x43hatTarget.proto\"l\n\x0cLeaveSession\x12\x35\n\nchatTarget\x18\x01 \x01(\x0b\x32!.AcFunDanmu.Im.Message.ChatTarget\x12\x11\n\textraInfo\x18\x02 \x01(\t\x12\x12\n\nactionType\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'LeaveSession_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LEAVESESSION._serialized_start=63
  _LEAVESESSION._serialized_end=171
# @@protoc_insertion_point(module_scope)



"""Methods for easy encoding and decoding of messages"""

import json
from .types import length_delim, type_maps

known_messages = {}


def bytes_to_string(obj):
    return obj.decode('utf8', 'backslashreplace')


def _get_json_writeable_obj(in_obj, out_obj, bytes_as_hex=False):
    """Converts non-string values (like bytes) to strings
    in lists/dictionaries recursively.
    """
    if isinstance(in_obj, list):
        for item in in_obj:
            if isinstance(item, list):
                i = []
                out_obj.append(i)
                _get_json_writeable_obj(item, i, bytes_as_hex)
            elif isinstance(item, dict):
                i = {}
                out_obj.append(i)
                _get_json_writeable_obj(item, i, bytes_as_hex)
            elif isinstance(item, bytes):
                if bytes_as_hex:
                    out_obj.append(item.hex())
                else:
                    out_obj.append(bytes_to_string(item))
            else:
                out_obj.append(str(item))
    else:  # dict
        for k, v in in_obj.items():
            if isinstance(v, list):
                i = []
                out_obj[k] = i
                _get_json_writeable_obj(v, i, bytes_as_hex)
            elif isinstance(v, dict):
                i = {}
                out_obj[k] = i
                _get_json_writeable_obj(v, i, bytes_as_hex)
            elif isinstance(v, bytes):
                if bytes_as_hex:
                    out_obj[k] = v.hex()
                else:
                    out_obj[k] = bytes_to_string(v)
            else:
                out_obj[k] = str(v)


def decode_message(buf, message_type=None):
    """Decode a message to a Python dictionary.
    Returns tuple of (values, types)
    """

    if message_type is None or isinstance(message_type, str):
        if message_type not in known_messages:
            message_type = {}
        else:
            message_type = known_messages[message_type]

    value, typedef, _ = length_delim.decode_message(buf, message_type)
    return value, typedef


# TODO add explicit validation of values to message type
def encode_message(value, message_type):
    """Encodes a python dictionary to a message.
    Returns a bytearray
    """
    return length_delim.encode_message(value, message_type)


def protobuf_to_json(buf, message_type=None, bytes_as_hex=False):
    """Encode to python dictionary and dump to JSON.
    """
    value, message_type = decode_message(buf, message_type)
    value_cleaned = {}
    _get_json_writeable_obj(value, value_cleaned, bytes_as_hex)
    return json.dumps(value_cleaned, indent=2, ensure_ascii=False), message_type


def protobuf_from_json(value, *args, **kwargs):
    """Decode JSON string to JSON and then to protobuf.
    Takes same arguments as encode_message
    """
    return encode_message(json.loads(value), *args, **kwargs)


def validate_typedef(typedef, old_typedef=None):
    """Validate the typedef format. Optionally validate wiretype of a field
       number has not been changed
    """
    # TODO record "path" and print out context for errors
    int_keys = set()
    for field_number, field_typedef in typedef.items():
        alt_field_number = None
        if '-' in str(field_number):
            field_number, alt_field_number = field_number.split('-')

        # Validate field_number is a number
        if not str(field_number).isdigit():
            raise ValueError("Field number must be a digit: %s" % field_number)
        field_number = str(field_number)

        # Check for duplicate field numbers
        if field_number in int_keys:
            raise ValueError("Duplicate field number: %s" % field_number)
        int_keys.add(field_number)

        # Must have a type field
        if "type" not in field_typedef:
            raise ValueError("Field number must have a type value: %s" % field_number)
        if alt_field_number is not None:
            if field_typedef['type'] != 'message':
                raise ValueError(
                    "Alt field number (%s) specified for non-message field: %s"
                    % (alt_field_number, field_number))

        field_names = set()
        valid_type_fields = ["type", "name", "message_typedef",
                             "message_type_name", "group_typedef",
                             "alt_typedefs"]
        for key, value in field_typedef.items():
            # Check field keys against valid values
            if key not in valid_type_fields:
                raise ValueError("Invalid field key %s for field number %s" % (key, field_number))
            if (key in ["message_typedef", "message_type_name"]
                    and not field_typedef["type"] == "message"):
                raise ValueError("Invalid field key %s for field number %s" % (key, field_number))
            if key == "group_typedef" and not field_typedef["type"] == "group":
                raise ValueError("Invalid field key %s for field number %s" % (key, field_number))

            # Validate type value
            if key == "type":
                if value not in acfun.libs.blackboxprotobuf.libs.types.type_maps.wiretypes:
                    raise ValueError("Invalid type %s for field number %s" % (value, field_number))
            # Check for duplicate names
            if key == "name":
                if value in field_names:
                    raise ValueError("Duplicate field name %s for field number %s"
                                     % (value, field_number))
                field_names.add(value)

            # Check if message type name is known
            if key == "message_type_name":
                if value not in known_messages:
                    raise ValueError("Message type %s for field number %s is not known"
                                     % (value, field_number))

            # Recursively validate inner typedefs
            if key in ["message_typedef", "group_typedef"]:
                if old_typedef is None:
                    validate_typedef(value)
                else:
                    # print(old_typedef.keys())
                    validate_typedef(value, old_typedef[field_number][key])
            if key == "alt_typedefs":
                for alt_fieldnumber, alt_typedef in value.items():
                    # TODO validate alt_typedefs against old typedefs?
                    validate_typedef(alt_typedef)

    if old_typedef is not None:
        wiretype_map = {}
        for field_number, value in old_typedef.items():
            wiretype_map[int(field_number)] = type_maps.wiretypes[value['type']]
        for field_number, value in typedef.items():
            if int(field_number) in wiretype_map:
                old_wiretype = wiretype_map[int(field_number)]
                if old_wiretype != type_maps.wiretypes[value["type"]]:
                    raise ValueError("Wiretype for field number %s does not match old type definition"
                                     % field_number)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionSearchResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupMsgSearchResult_pb2 as GroupMsgSearchResult__pb2
import UserMsgSearchResult_pb2 as UserMsgSearchResult__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bSessionSearchResponse.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x1aGroupMsgSearchResult.proto\x1a\x19UserMsgSearchResult.proto\"\xa3\x01\n\x15SessionSearchResponse\x12\x43\n\nuserResult\x18\x01 \x03(\x0b\x32/.AcFunDanmu.Im.Cloud.Search.UserMsgSearchResult\x12\x45\n\x0bgroupResult\x18\x02 \x03(\x0b\x32\x30.AcFunDanmu.Im.Cloud.Search.GroupMsgSearchResultb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionSearchResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONSEARCHRESPONSE._serialized_start=115
  _SESSIONSEARCHRESPONSE._serialized_end=278
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupMember.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11GroupMember.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\nUser.proto\"\xa8\x04\n\x0bGroupMember\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12\x16\n\x0e\x61ntiDisturbing\x18\x03 \x01(\x08\x12J\n\x06status\x18\x04 \x01(\x0e\x32:.AcFunDanmu.Im.Cloud.Message.GroupMember.GroupMemberStatus\x12\x11\n\tinviterId\x18\x05 \x01(\x03\x12\x10\n\x08joinTime\x18\x06 \x01(\x03\x12\x12\n\ncreateTime\x18\x07 \x01(\x03\x12\x12\n\nupdateTime\x18\x08 \x01(\x03\x12\x46\n\x04role\x18\t \x01(\x0e\x32\x38.AcFunDanmu.Im.Cloud.Message.GroupMember.GroupMemberRole\x12\x10\n\x08\x66indType\x18\n \x01(\x05\x12\x1b\n\x13keepSilenceDeadline\x18\x0b \x01(\x03\"b\n\x11GroupMemberStatus\x12\x19\n\x15UNKNOWN_MEMBER_STATUS\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x0b\n\x07QUITTED\x10\x02\x12\n\n\x06KICKED\x10\x03\x12\r\n\tDISMISSED\x10\x04\"R\n\x0fGroupMemberRole\x12\x10\n\x0cUNKNOWN_ROLE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41\x44MIN\x10\x02\x12\x0b\n\x07MANAGER\x10\x03\x12\t\n\x05ROBOT\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupMember_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPMEMBER._serialized_start=63
  _GROUPMEMBER._serialized_end=615
  _GROUPMEMBER_GROUPMEMBERSTATUS._serialized_start=433
  _GROUPMEMBER_GROUPMEMBERSTATUS._serialized_end=531
  _GROUPMEMBER_GROUPMEMBERROLE._serialized_start=533
  _GROUPMEMBER_GROUPMEMBERROLE._serialized_end=615
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserOnlineStatus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16UserOnlineStatus.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Profile\x1a\nUser.proto\"\xca\x01\n\x10UserOnlineStatus\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x17\n\x0flastOfflineTime\x18\x02 \x01(\x03\x12\x44\n\x06status\x18\x03 \x01(\x0e\x32\x34.AcFunDanmu.Im.Cloud.Profile.UserOnlineStatus.Status\".\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\x0b\n\x07OFFLINE\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserOnlineStatus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERONLINESTATUS._serialized_start=68
  _USERONLINESTATUS._serialized_end=270
  _USERONLINESTATUS_STATUS._serialized_start=224
  _USERONLINESTATUS_STATUS._serialized_end=270
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: EnvInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rEnvInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\x90\x01\n\x07\x45nvInfo\x12=\n\x0bnetworkType\x18\x01 \x01(\x0e\x32(.AcFunDanmu.Im.Basic.EnvInfo.NetworkType\x12\x0f\n\x07\x61pnName\x18\x02 \x01(\x0c\"5\n\x0bNetworkType\x12\x0c\n\x08kInvalid\x10\x00\x12\t\n\x05kWIFI\x10\x01\x12\r\n\tkCellular\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'EnvInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVINFO._serialized_start=39
  _ENVINFO._serialized_end=183
  _ENVINFO_NETWORKTYPE._serialized_start=130
  _ENVINFO_NETWORKTYPE._serialized_end=183
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PacketHeader.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import TokenInfo_pb2 as TokenInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12PacketHeader.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\x0fTokenInfo.proto\"\x84\x05\n\x0cPacketHeader\x12\r\n\x05\x61ppId\x18\x01 \x01(\x05\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12\x12\n\ninstanceId\x18\x03 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12\x44\n\x0c\x65ncodingType\x18\x06 \x01(\x0e\x32..AcFunDanmu.Im.Basic.PacketHeader.EncodingType\x12\x19\n\x11\x64\x65\x63odedPayloadLen\x18\x07 \x01(\r\x12H\n\x0e\x65ncryptionMode\x18\x08 \x01(\x0e\x32\x30.AcFunDanmu.Im.Basic.PacketHeader.EncryptionMode\x12\x31\n\ttokenInfo\x18\t \x01(\x0b\x32\x1e.AcFunDanmu.Im.Basic.TokenInfo\x12\r\n\x05seqId\x18\n \x01(\x03\x12;\n\x08\x66\x65\x61tures\x18\x0b \x03(\x0e\x32).AcFunDanmu.Im.Basic.PacketHeader.Feature\x12\x0b\n\x03kpn\x18\x0c \x01(\t\"?\n\x05\x46lags\x12\x10\n\x0ckDirUpstream\x10\x00\x12\x12\n\x0ekDirDownstream\x10\x01\x12\x0c\n\x08kDirMask\x10\x01\x1a\x02\x10\x01\"3\n\x0c\x45ncodingType\x12\x11\n\rkEncodingNone\x10\x00\x12\x10\n\x0ckEncodingLz4\x10\x01\"]\n\x0e\x45ncryptionMode\x12\x13\n\x0fkEncryptionNone\x10\x00\x12\x1b\n\x17kEncryptionServiceToken\x10\x01\x12\x19\n\x15kEncryptionSessionKey\x10\x02\")\n\x07\x46\x65\x61ture\x12\x0c\n\x08kReserve\x10\x00\x12\x10\n\x0ckCompressLz4\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PacketHeader_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PACKETHEADER_FLAGS._options = None
  _PACKETHEADER_FLAGS._serialized_options = b'\020\001'
  _PACKETHEADER._serialized_start=61
  _PACKETHEADER._serialized_end=705
  _PACKETHEADER_FLAGS._serialized_start=451
  _PACKETHEADER_FLAGS._serialized_end=514
  _PACKETHEADER_ENCODINGTYPE._serialized_start=516
  _PACKETHEADER_ENCODINGTYPE._serialized_end=567
  _PACKETHEADER_ENCRYPTIONMODE._serialized_start=569
  _PACKETHEADER_ENCRYPTIONMODE._serialized_end=662
  _PACKETHEADER_FEATURE._serialized_start=664
  _PACKETHEADER_FEATURE._serialized_end=705
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TopBannerNotice.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import BackgroundStyle_pb2 as BackgroundStyle__pb2
import Button_pb2 as Button__pb2
import ImageCdnNode_pb2 as ImageCdnNode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15TopBannerNotice.proto\x12\nAcFunDanmu\x1a\x15\x42\x61\x63kgroundStyle.proto\x1a\x0c\x42utton.proto\x1a\x12ImageCdnNode.proto\"\xb4\x01\n\x0fTopBannerNotice\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\t\x12\t\n\x01\x63\x18\x03 \x01(\t\x12&\n\x01\x64\x18\x04 \x01(\x0b\x32\x1b.AcFunDanmu.BackgroundStyle\x12\t\n\x01\x65\x18\x05 \x01(\x05\x12\x1d\n\x01\x66\x18\x06 \x01(\x0b\x32\x12.AcFunDanmu.Button\x12#\n\x01g\x18\x07 \x03(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12\t\n\x01h\x18\x08 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'TopBannerNotice_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOPBANNERNOTICE._serialized_start=95
  _TOPBANNERNOTICE._serialized_end=275
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalChatCall.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatMediaType_pb2 as ChatMediaType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x43ommonStateSignalChatCall.proto\x12\nAcFunDanmu\x1a\x13\x43hatMediaType.proto\"\x82\x01\n\x19\x43ommonStateSignalChatCall\x12\x0e\n\x06\x63hatId\x18\x01 \x01(\t\x12\x0e\n\x06liveId\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x61llTimestampMs\x18\x03 \x01(\x03\x12,\n\tmediaType\x18\x04 \x01(\x0e\x32\x19.AcFunDanmu.ChatMediaTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalChatCall_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALCHATCALL._serialized_start=69
  _COMMONSTATESIGNALCHATCALL._serialized_end=199
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalAuthorChatAccept.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'CommonStateSignalAuthorChatAccept.proto\x12\nAcFunDanmu\"Q\n!CommonStateSignalAuthorChatAccept\x12\x14\n\x0c\x61uthorChatId\x18\x01 \x01(\t\x12\x16\n\x0e\x61ryaSignalInfo\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalAuthorChatAccept_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALAUTHORCHATACCEPT._serialized_start=55
  _COMMONSTATESIGNALAUTHORCHATACCEPT._serialized_end=136
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CPullOldResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Message_pb2 as Message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x42\x32\x43PullOldResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\rMessage.proto\"Z\n\x12\x42\x32\x43PullOldResponse\x12\x30\n\x08messages\x18\x01 \x03(\x0b\x32\x1e.AcFunDanmu.Im.Message.Message\x12\x12\n\nserverTime\x18\x02 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CPullOldResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CPULLOLDRESPONSE._serialized_start=66
  _B2CPULLOLDRESPONSE._serialized_end=156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SdkOption.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fSdkOption.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\x81\x01\n\tSdkOption\x12\x1d\n\x15reportIntervalSeconds\x18\x01 \x01(\x05\x12\x16\n\x0ereportSecurity\x18\x02 \x01(\t\x12$\n\x1clz4CompressionThresholdBytes\x18\x03 \x01(\x05\x12\x17\n\x0fnetCheckServers\x18\x04 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SdkOption_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SDKOPTION._serialized_start=41
  _SDKOPTION._serialized_end=170
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionTagSyncResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionTagBasic_pb2 as SessionTagBasic__pb2
import SyncCookie_pb2 as SyncCookie__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cSessionTagSyncResponse.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.SessionTag\x1a\x15SessionTagBasic.proto\x1a\x10SyncCookie.proto\"\x92\x01\n\x16SessionTagSyncResponse\x12\x33\n\nsyncCookie\x18\x01 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.SyncCookie\x12\x43\n\nsessionTag\x18\x02 \x03(\x0b\x32/.AcFunDanmu.Im.Cloud.SessionTag.SessionTagBasicb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionTagSyncResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONTAGSYNCRESPONSE._serialized_start=106
  _SESSIONTAGSYNCRESPONSE._serialized_end=252
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Attachment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AudioAttachment_pb2 as AudioAttachment__pb2
import ImageAttachment_pb2 as ImageAttachment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x41ttachment.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x15\x41udioAttachment.proto\x1a\x15ImageAttachment.proto\"\xa0\x01\n\nAttachment\x12\x41\n\x0fimageAttachment\x18\x01 \x01(\x0b\x32&.AcFunDanmu.Im.Message.ImageAttachmentH\x00\x12\x41\n\x0f\x61udioAttachment\x18\x02 \x01(\x0b\x32&.AcFunDanmu.Im.Message.AudioAttachmentH\x00\x42\x0c\n\nattachmentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Attachment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ATTACHMENT._serialized_start=90
  _ATTACHMENT._serialized_end=250
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalChatReady.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatMediaType_pb2 as ChatMediaType__pb2
import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n CommonStateSignalChatReady.proto\x12\nAcFunDanmu\x1a\x13\x43hatMediaType.proto\x1a\x14ZtLiveUserInfo.proto\"\x8d\x01\n\x1a\x43ommonStateSignalChatReady\x12\x0e\n\x06\x63hatId\x18\x01 \x01(\t\x12\x31\n\rguestUserInfo\x18\x02 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12,\n\tmediaType\x18\x03 \x01(\x0e\x32\x19.AcFunDanmu.ChatMediaTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalChatReady_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALCHATREADY._serialized_start=92
  _COMMONSTATESIGNALCHATREADY._serialized_end=233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClickEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveCommonModelProto_pb2 as ZtLiveCommonModelProto__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x43lickEvent.proto\x12\nAcFunDanmu\x1a\x1cZtLiveCommonModelProto.proto\"e\n\nClickEvent\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x33\n\x07urlType\x18\x02 \x01(\x0e\x32\".AcFunDanmu.ZtLiveCommonModelProto\x12\x15\n\rheightPercent\x18\x03 \x01(\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ClickEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLICKEVENT._serialized_start=62
  _CLICKEVENT._serialized_end=163
# @@protoc_insertion_point(module_scope)
